# Title

The description describes this recipe. It is delicious!

It can have multiple lines an may even include pictures.

<img src="../logo/recipemd-mark.svg" />

*vegetarian, vegan, not a real recipe*

**5 cups, 20 ml, 5.5 Tassen**

---

- *5* ungrouped ingredient
- *5.2 ml* grouped ingredient

## Group 1

- *1* [link ingredient](./ingredients.md)
- unit is optional

### Subgroup 1.1

- *1.25 ml* ingredient

## Group 2

- text isn't optional
- *hey* amount is valid without factor

---

Instructions are very instructive.